#!/bin/sh
#
# INSTALL_ORiNOCO_USB.sh 0.2
# * A simple but usefull script for build, install and upgrade
#   the Linux drivers for Lucent/Agere Orinoco USB devices.
#
# Changelog
# =========
#
# 2003/05/27: release 0.2
#   - New improved code
#   - Added more additional test code
#   - Deleted "fwfs option"
#
# 2003/05/21: release 0.1.1
#   - Applied patch from Ranty <ranty@debian.org>. Now the
#       trivial bug for show_info_installation is fixed and
#       for FHS compatibility, fwfs is mounted on /fwfs
#   - Some additional test coded added.
#
# 2003/05/20: release 0.1
#   - Initial release
#   - Basic features implemented
#      * Show a simple menu to choose build type
#      * Build, install and upgrade the modules properly 
#          in the system
#
# Copyright (C) 2003  Ramn Rey Vicente <ramon.rey@hispalinux.es>
#  
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or 
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


MODULES_PATH=/lib/modules/$(uname -r)
KERNEL_SRC=$MODULES_PATH/build
ORINOCO_USB_PATH=$MODULES_PATH/orinoco_usb

# Check what user is running the script.
# If is not the superuser, the user is warned about it.
check_user()
{
	USER=$(whoami)
	clear

	if [ "$USER" != "root" ]; then
		echo "	#################################################"
		echo "	# You need to login as root for run this script #"
		echo "	#################################################"
	exit 1
	fi
}


# As superuser, the script ask for the type of installation
installation_type()
{
	clear
	echo 
	echo "	Linux driver effort for Lucent/Agere Orinoco USB devices"
	echo "	========================================================"
	echo
	echo "	Choose an option: (and press enter)"
	echo "	---------------------------"
	echo
	echo "		i) Build and install the driver"
	echo
	echo "		h) See README file"
	echo
	echo "		n) View the NEWS file"	
	echo
	echo
	read INSTALLATION_TYPE

	if [ $INSTALLATION_TYPE == "h" ]; then
		less README
	fi
	if [ $INSTALLATION_TYPE == "n" ]; then
	        less NEWS
	fi
				
}


# Installation with fwfs support. Need inkernel hotplug support.
build_and_install_modules()
{
	make clean
	
	case $INSTALLATION_TYPE in
	"i")	
		make inkernel-firmware
		break
		;;
	*)
		echo "That option is not available"
		# This should never happen
		;;
	esac	
	
	make

	mkdir $ORINOCO_USB_PATH

	cp driver/fwfs.o $ORINOCO_USB_PATH
	cp driver/hermes.o $ORINOCO_USB_PATH
	cp driver/orinoco.o $ORINOCO_USB_PATH
	cp driver/orinoco_usb.o $ORINOCO_USB_PATH
	
	depmod -ae
}

# Check previous installations and remove it
uninstall_previous_installation()
{
	if [ -d $ORINOCO_USB_PATH ]; then
		rm -f $ORINOCO_USB_PATH/*
		rmdir $ORINOCO_USB_PATH
		UPGRADE_MODULES=1
	else
		UPGRADE_MODULES=0
	fi
}


# Show the information about the installation directories and 
show_info_installation()
{
	clear	
	echo
	echo "Congratulations! The installation have finished succesfully."
	echo "============================================================"
	echo
	echo "* The modules have been installed in $ORINOCO_USB_PATH"
	echo
}


# Load the modules properly
load_the_modules()
{
	
	echo
	echo "Do you like I try to load the new modules now?"
	echo
	echo "	Warning! If you have a previous installation of this drivers "
	echo "	and the modules are already loaded, you could get an error message."
	echo
	echo "(y/n)"
	echo
	read LOAD_MODULES

	if [ $LOAD_MODULES == "y" ]; then
	
		if [ $UPGRADE_MODULES == 0 ]; then
			
			insmod fwfs
			insmod hermes
			insmod orinoco
			insmod orinoco_usb
		
		else
			clear
			echo
			echo "It seems that there is an old version of this"
			echo "drivers on your system. You need to unload them"
			echo
			echo "	rmmod orinoco_usb"
			echo "	rmmod orinoco"
			echo "	rmmod hermes"
			echo "	rmmod fwfs"
			echo
			echo "and then load the new ones by tipying:"
			echo 
			echo "	insmod fwfs"
			echo "	insmod hermes"
			echo "	insmod orinoco"
			echo "	insmod orinoco_usb"
			echo
			echo "... or reboot your system :)"
		fi
	fi
}
    

check_user

while [ "$INSTALLATION_TYPE" != "i" ] 
do
		installation_type
done

uninstall_previous_installation

build_and_install_modules

load_the_modules

show_info_installation
